/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::Network
 * Copyright (c) 2004-2014 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    Telnet_Server.c
 * Purpose: Telnet Server example
 *----------------------------------------------------------------------------*/

#include <stdio.h>
#include "cmsis_os.h"                   /* CMSIS RTOS definitions             */
#include "rl_net.h"                     /* Network definitions                */

#include "SCU_LPC43xx.h"                // Keil::Device:SCU
#include "GPIO_LPC43xx.h"               // Keil::Device:GPIO

#include "Board_LED.h"

bool LEDrun;

static void BlinkLed (void const *arg);    

osThreadDef(BlinkLed, osPriorityNormal, 1, 0);

/// Read analog inputs
uint16_t AD_in (uint32_t ch) {
  static int32_t val = 0;

  if (ch == 0) {
    val++;
    val &= 0x3FF;
  }
  return (val);
}

/// IP address change notification
void dhcp_client_notify (uint32_t if_num,
                         dhcpClientOption opt, const uint8_t *val, uint32_t len) {
  if (opt == dhcpClientIPaddress) {
    // IP address has changed
  }
}

/*----------------------------------------------------------------------------
  Thread 'BlinkLed': Blink the LEDs on an eval board
 *---------------------------------------------------------------------------*/
static void BlinkLed (void const *arg) {
  const uint8_t led_val[4] = { 0x01,0x03,0x02,0x00,};

  int cnt = 0;

  LEDrun = true;
  while(1) {
    // Every 100 ms
    if (LEDrun == true) {
      LED_SetOut (led_val[cnt]);
      if (++cnt >= sizeof(led_val)) {
        cnt = 0;
      }
    }
    osDelay (100);
  }
}

/*----------------------------------------------------------------------------
  Main Thread 'main': Run Network
 *---------------------------------------------------------------------------*/
int main (void) {

  /* LAN8720 on LPC430-Xplorer uses a GPIO for nRST */
  GPIO_PortClock (1);
  GPIO_SetDir   (0, 4, GPIO_DIR_OUTPUT);
  GPIO_PinWrite (0, 4, 1);
  SCU_PinConfigure (1, 0, SCU_CFG_MODE_FUNC0);

  LED_Initialize ();
  net_initialize ();

  osThreadCreate (osThread(BlinkLed), NULL);

  while(1) {
    net_main ();
    osThreadYield ();
  }
}
